@@ -1,15 +1,15 @@
 package XFST::Lookup;
 
-# $Header: /var/cvsroot/XFST-Lookup/lib/XFST/Lookup.pm,v 1.27 2005/07/17 08:44:33 alex Exp $
+# $Header: /var/cvsroot/XFST-Lookup/lib/XFST/Lookup.pm,v 1.29 2005/07/24 15:53:17 alex Exp $
 
-$VERSION="0.10";
+$VERSION="0.11";
 
 use strict;
 use Carp;
 
 =head1 NAME
 
-XFST::Lookup - PERL extension to access *XEROX*'s lookup-utility
+XFST::Lookup - Perl extension to access *XEROX*'s lookup-utility
 
 =head1 SYNOPSIS
     
@@ -33,7 +33,7 @@ XFST::Lookup - PERL extension to access *XEROX*'s lookup-utility
 =head1 DESCRIPTION
 
 XFST::Lookup() provides an easy way to access the functionality of the
-*XEROX* lookup-utility from within PERL.
+*XEROX* lookup-utility from within Perl.
 I<lookup> itself "applies a pre-compiled transducer or transducers to
 look up words".
 
@@ -68,7 +68,7 @@ sub _check4bin {
     print "Looking for '$binary'... " if $self->{debug};
 
     # try to locate xfst's lookup (or any other binary) (in $ENV{PATH})
-    if ( $^O =~ /linux|bsd|darwin/ ) {
+    if ( $^O =~ /linux|bsd|darwin|cygwin/ ) {
         # got a user-defined path? add to $ENV{PATH}
         $ENV{PATH} .= ":$self->{path}" if $self->{path};
         
@@ -198,7 +198,7 @@ lookup-utility. See [3] for a brief overview.
 
 Please note: even if you set them manually, the 'LxL' and 'TxT'-flags are
 stripped, in order to do what you mean. XFST::Lookup needs the default
-separators in order to correctly process lookup's output.
+separators in order to correctly process the output of lookup.
 
 =back
 
@@ -225,7 +225,7 @@ sub set_flags {
 =over 2
 
 ... is the most important method of XFST::Lookup (like the name may already
-suggest). Every time lookup() is invoked from the inside of a PERL-program,
+suggest). Every time lookup() is invoked from the inside of a Perl-program,
 *XEROX*'s lookup-utility is called with the given options and all results
 are returned as a I<hash of arrays>. This datastructure has been chosen
 because there may be ambiguous wordforms so a simple hash won't fulfill
@@ -282,7 +282,7 @@ the current run _only_. see CONSTRUCTOR
 
 =item I<strategy> [path]
 
-set parameter to the path to the stratgy-file if you want to use a
+set parameter to the path to the strategy-file if you want to use a
 lookup-strategy rather than a single finite state transducer.
 
 Conflicts with the I<fst>-parameter.
@@ -391,7 +391,7 @@ sub lookup {
         # write all wordforms to the tempfile...
         print $tmp join("\n", @{$opt->{words}}), "\n";
         
-        # ... use PERL as kind of cat-command to pipe the wordforms to
+        # ... use Perl as kind of cat-command to pipe the wordforms to
         # lookup. This looks terribly ugly, but the Win32 echo-command
         # doesn't even seem to handle escape-sequences, which are required
         # in order to get some useful results out of lookup.
@@ -430,7 +430,8 @@ sub lookup {
 
     # extract information from lookup's output
     foreach my $line ( @output ) {
-        chomp $line;
+        # cygwin's lookup-output contains "\r", so we can't just chomp()
+        $line =~ s/[\n\r]//g;
         next unless $line;
 
         # match the three fields ( 1x input, 2x parts analysis(base+tags) )
